@@ -78,8 +78,9 @@ class Chalice(cdk.Construct):
 
     # pylint: disable=redefined-builtin
     # The 'id' parameter name is CDK convention.
-    def __init__(self, scope: cdk.Construct, id: str, *, source_dir: str, stage_config: dict,
-                 package_config: PackageConfig = None, **kwargs) -> None:
+    def __init__(self, scope: cdk.Construct, id: str, *, source_dir: str,
+                 stage_config: dict, package_config: PackageConfig = None,
+                 preserve_logical_ids: bool = True, **kwargs) -> None:
         """
         :param str source_dir: Path to Chalice application source code.
         :param dict stage_config: Chalice stage configuration.
@@ -87,6 +88,13 @@ class Chalice(cdk.Construct):
             stage configuration.
         :param `PackageConfig` package_config: Configuration for packaging the
             Chalice application.
+        :param bool preserve_logical_ids: Whether the resources should have the same
+            logical IDs in the resulting CDK template as they did in the original
+            CloudFormation template file. If you’re vending a Construct using cdk-chalice,
+            make sure to pass this as ``False``. Note: regardless of whether this option
+            is true or false, the :attr:`sam_template`'s ``get_resource`` and related
+            methods always uses the original logical ID of the resource/element, as
+            specified in the template file.
         :raises `ChaliceError`: Error packaging the Chalice application.
         """
         super().__init__(scope, id, **kwargs)
@@ -122,7 +130,8 @@ class Chalice(cdk.Construct):
         #: access, and customize resources generated by `chalice package` command
         #: as CDK native objects.
         self.sam_template = cloudformation_include.CfnInclude(
-            self, 'ChaliceApp', template_file=sam_template_with_assets_file)
+            self, 'ChaliceApp', template_file=sam_template_with_assets_file,
+            preserve_logical_ids=preserve_logical_ids)
 
     def _create_stage_with_config(self) -> None:
         config_path = os.path.join(self.source_dir, '.chalice/config.json')
